@@ -2,7 +2,16 @@ class CommandPool(object):
     processes = []
     polls = []
 
-    def run_command(self, command):
+    def run_command(self, command, working_dir=None):
+        import os
+
+        abs_working_dir = None
+        if working_dir != None:
+            if (os.path.isdir(working_dir)) == False:
+                print("%s does NOT exists." % working_dir)
+                return
+            abs_working_dir = os.path.abspath(working_dir)
+
         import subprocess
 
         process1 = subprocess.Popen(
@@ -12,6 +21,7 @@ class CommandPool(object):
                 "start-process cmd -Wait -ArgumentList '/C %s'" % command,
             ],
             shell=False,
+            cwd=abs_working_dir,
             stdout=subprocess.PIPE,
         )
         self.processes.append(process1)
